@@ -25,6 +25,6 @@ def download(url, fpn):
     print('downloaded!')
     return
 
-#
-# if __name__ == '__main__':
-#     main()
\ No newline at end of file
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
